from django.test import TestCase
from django.test import RequestFactory
from django.contrib.sessions.middleware import SessionMiddleware
from taskdatabase.models import Task, Workflow, Activity
from taskdatabase.views import get_filtered_tasks

class FiltersTest(TestCase):
    def setUp(self):
        self.workflow_requantisation = Workflow(id=22, workflow_uri="psrfits_requantisation")
        self.workflow_requantisation.save()
        self.activity_12345 = Activity.objects.create(sas_id=12345)
        self.activity_12345.save()
        self.activity_66666 = Activity.objects.create(sas_id=66666)
        self.activity_66666.save()
        self.task1 = Task.objects.create(sas_id=12345, status='defined', workflow=self.workflow_requantisation, activity = self.activity_12345)
        self.task2 = Task.objects.create(sas_id=12345, status='scrubbed', workflow=self.workflow_requantisation, activity = self.activity_12345)
        self.task3 = Task.objects.create(sas_id=12345, status='scrubbed', workflow=self.workflow_requantisation, activity = self.activity_12345)
        self.task4 = Task.objects.create(sas_id=66666, status='scrubbed', workflow=self.workflow_requantisation, activity = self.activity_66666)
        self.task5 = Task.objects.create(sas_id=66666, status='archived_failed', workflow=self.workflow_requantisation, activity = self.activity_66666)

    def test_without_filter(self):
        count = 0
        for task in Task.objects.all():
            count += 1

        self.assertEqual(count,5)

    def test_with_ingest_filter(self):
        # create a request object
        request = RequestFactory().get('/atdb/ingest')

        # this simulates the 'Queue (scrubbed)' filter on the ingest page
        request.session = {'ingest_filter': 'scrubbed'}

        # after aggregating per sas_id, 2 objects with status 'scrubbed' remain
        tasks = get_filtered_tasks(request, None, "sas_id")
        self.assertEqual(tasks.count(), 2)
